@@ -19,38 +19,45 @@
 class KMahjonggConfigDialogPrivate
 {
 public:
-    KConfigSkeleton * m_config;
+    explicit KMahjonggConfigDialogPrivate(KConfigSkeleton *config)
+        : m_config(config)
+    {}
+
+public:
+    KConfigSkeleton *m_config;
 };
 
-KMahjonggConfigDialog::KMahjonggConfigDialog(QWidget * parent, const QString & name,
-                                             KConfigSkeleton * config)
+KMahjonggConfigDialog::KMahjonggConfigDialog(QWidget *parent, const QString &name, KConfigSkeleton *config)
     : KConfigDialog(parent, name, config)
-    , d(new KMahjonggConfigDialogPrivate)
+    , d_ptr(new KMahjonggConfigDialogPrivate(config))
 {
     setFaceType(List);
     setModal(true);
-    d->m_config = config;
 }
 
 KMahjonggConfigDialog::~KMahjonggConfigDialog() = default;
 
 void KMahjonggConfigDialog::addTilesetPage()
 {
-    KMahjonggTilesetSelector * ts = new KMahjonggTilesetSelector(this, d->m_config);
-    //TODO: Use the cards icon for our page for now, need to get one for tilesets made
+    Q_D(KMahjonggConfigDialog);
+
+    auto *ts = new KMahjonggTilesetSelector(this, d->m_config);
+    // TODO: Use the cards icon for our page for now, need to get one for tilesets made
     addPage(ts, i18n("Tiles"), QStringLiteral("games-config-tiles"));
 }
 
 void KMahjonggConfigDialog::addBackgroundPage()
 {
-    KMahjonggBackgroundSelector * ts = new KMahjonggBackgroundSelector(this, d->m_config);
-    //TODO: need icon
+    Q_D(KMahjonggConfigDialog);
+
+    auto *ts = new KMahjonggBackgroundSelector(this, d->m_config);
+    // TODO: need icon
     addPage(ts, i18n("Background"), QStringLiteral("games-config-background"));
 }
 
 void KMahjonggConfigDialog::updateWidgetsDefault()
 {
-    //qCDebug(LIBKMAHJONGG_LOG) << "updateWidgetsDefault";
+    // qCDebug(LIBKMAHJONGG_LOG) << "updateWidgetsDefault";
 }
 
 #include "moc_kmahjonggconfigdialog.cpp"
